@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: config.c,v 1.51 2007/07/12 22:21:08 hany Exp $
+ * $Id: config.c,v 1.52 2010/11/09 22:16:29 hany Exp $
  */
 
 #include <config.h>
@@ -52,6 +52,7 @@ int   rpm2html_cve_linking      = 1;
 char *rpm2html_html_template	= "rpm2html.tpl";
 #endif
 int   rpm2html_dump_html	= 1;
+int   rpm2html_dump_html_only_if_rpm_newer = 0;
 int   rpm2html_dump_rdf		= 0;
 int   rpm2html_dump_rdf_resources= 0;
 char *rpm2html_rdf_dir		= NULL;
@@ -368,6 +369,17 @@ void addConfigEntry(char *rpmdir, char *name, char *value) {
 	    }
 	} else if (!strcasecmp(name, "header")) {
 	    addHeader(value);
+	} else if (!strcasecmp(name, "dump_html_only_if_rpm_newer")) {
+	    if ((!strcasecmp(value, "true")) ||
+	        (!strcasecmp(value, "yes"))) {
+	        rpm2html_dump_html_only_if_rpm_newer = 1;
+	    } else if ((!strcasecmp(value, "false")) ||
+	        (!strcasecmp(value, "no"))) {
+	        rpm2html_dump_html_only_if_rpm_newer = 0;
+	    } else {
+		printf("Config file : %s global entry ignored,\n", name);
+		printf("\tuse \"dump_html_only_if_rpm_newer=true\" or \"dump_html_only_if_rpm_newer=false\"\n");
+	    }
         } else {
 	    printf("Config file : %s global entry ignored\n", name);
 	}
