@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmdata.c,v 1.53 2005/03/16 20:17:12 hany Exp $
+ * $Id: rpmdata.c,v 1.54 2008/11/13 23:56:21 hany Exp $
  */
 
 #include <config.h>
@@ -912,7 +912,6 @@ char *protectEmail(char *string) {
 
     unsigned char *cur, *end;
     unsigned char c;
-    int magick = 0;
 
     if (buffer == NULL) {
         buffer = (char *) xmlMalloc(buffer_size * sizeof(char));
@@ -938,11 +937,7 @@ char *protectEmail(char *string) {
 	    cur = &buffer[delta];
 	}
         c = (unsigned char) *(string++);
-        if (c == '<')
-            magick = 1;
-        if (c == '>')
-            magick = 0;
-	if (c == '@' && magick) {
+	if (c == '@') {
 	    strcpy(cur, at);
 	    cur += strlen(at);
 	} else {
